@@ -13,12 +13,15 @@ use warnings;
 
 use Carp qw(croak);
 
-our $VERSION = '0.10';
+our $VERSION = '0.12';
 
 # This limit is set for various things under OpenSSH code. Used here to
 # limit length of authorized_keys lines.
 my $MAX_PUBKEY_BYTES = 8192;
 
+# Sanity check to ensure at least some data exists in the key field
+my $MIN_KEY_LENGTH = 42;
+
 # Delved from sshd(8), auth-options.c of OpenSSH 5.2. Insensitive match
 # required, as OpenSSH uses strncasecmp(3).
 my $AUTHKEY_OPTION_NAME_RE = qr/(?i)[a-z0-9_-]+/;
@@ -227,6 +230,29 @@ sub parse {
   return $self;
 }
 
+sub as_string {
+  my $self   = shift;
+  my $string = q{};
+
+  if ( @{ $self->{_parsed_options} } > 0 ) {
+    $string .= $_parsed_options_as_string->($self) . q{ };
+
+  } elsif ( exists $self->{_options} and length $self->{_options} > 0 ) {
+    $string .= $self->{_options} . q{ };
+  }
+
+  if ( !defined $self->{_key} or length $self->{_key} < $MIN_KEY_LENGTH ) {
+    croak('no key material present');
+  }
+  $string .= $self->{_key};
+
+  if ( exists $self->{_comment} and length $self->{_comment} > 0 ) {
+    $string .= q{ } . $self->{_comment};
+  }
+
+  return $string;
+}
+
 sub key {
   my $self = shift;
   my $key  = shift;
@@ -236,15 +262,18 @@ sub key {
       croak($err_msg);
     }
   }
+  if ( !defined $self->{_key} or length $self->{_key} < $MIN_KEY_LENGTH ) {
+    croak('no key material present');
+  }
   return $self->{_key};
 }
 
 sub protocol {
-  shift->{_protocol};
+  shift->{_protocol} || 0;
 }
 
 sub keytype {
-  shift->{_keytype};
+  shift->{_keytype} || '';
 }
 
 sub comment {
@@ -275,7 +304,8 @@ sub options {
     $self->{_options}        = $new_options;
   }
 
-  my $options_str = @{ $self->{_parsed_options} } > 0
+  my $options_str =
+    @{ $self->{_parsed_options} } > 0
     ? $_parsed_options_as_string->($self)
     : $self->{_options};
   return defined $options_str ? $options_str : '';
@@ -301,7 +331,7 @@ sub get_option {
     map { $_->{value} || $option_name }
     grep { $_->{name} eq $option_name } @{ $self->{_parsed_options} };
 
-  return wantarray ? @values : $values[0];
+  return wantarray ? @values : defined $values[0] ? $values[0] : '';
 }
 
 # Sets an option. To enable a boolean option, only supply the option
@@ -355,26 +385,6 @@ sub unset_option {
   return $record_count - @{ $self->{_parsed_options} };
 }
 
-sub as_string {
-  my $self   = shift;
-  my $string = q{};
-
-  if ( @{ $self->{_parsed_options} } > 0 ) {
-    $string .= $_parsed_options_as_string->($self) . q{ };
-
-  } elsif ( exists $self->{_options} and length $self->{_options} > 0 ) {
-    $string .= $self->{_options} . q{ };
-  }
-
-  $string .= $self->{_key};
-
-  if ( exists $self->{_comment} and length $self->{_comment} > 0 ) {
-    $string .= q{ } . $self->{_comment};
-  }
-
-  return $string;
-}
-
 sub duplicate_of {
   my $self = shift;
   my $ref  = shift;
@@ -386,6 +396,12 @@ sub duplicate_of {
   return $self->{_dup_of};
 }
 
+sub unset_duplicate {
+  my $self = shift;
+  $self->{_dup_of} = 0;
+  return 1;
+}
+
 1;
 
 __END__
@@ -431,7 +447,7 @@ parse.
 
 =item B<split_options> I<option string>
 
-Accepts a string of comma seperated options, and parses these into a
+Accepts a string of comma separated options, and parses these into a
 list of hash references. In scalar context, returns a reference to the
 list. In list context, returns a list.
 
@@ -451,6 +467,8 @@ Returns the public key material. If passed a string, will attempt to
 parse that string as a new key (and options, and comment, if those
 are present).
 
+Throws an exception if no key material present in the instance.
+
 =item B<keytype>
 
 Returns the type of the key, either C<rsa1> for a SSHv1 key, or C<rsa>
@@ -506,8 +524,9 @@ string value. Assuming the options have been set as shown above:
   # returns '127.0.0.1'
   $entry->get_option('from');
 
-In scalar context, only the first option is returned. In list context, a
-list of one (or rarely more) values will be returned.
+In scalar context, only the first option is returned (or the empty
+string). In list context, a list of one (or rarely more) values will be
+returned (or the empty list).
 
 =item B<set_option> I<option name>, I<optional value>
 
@@ -521,7 +540,7 @@ for that option.
   $entry->set_option(from => '127.0.0.1');
 
 If multiple options with the same name are present in the options list,
-only the first option found will be updated, and all subseqent entries
+only the first option found will be updated, and all subsequent entries
 removed from the options list.
 
 =item B<unset_option> I<option name>
@@ -530,7 +549,8 @@ Deletes all occurrences of the named option.
 
 =item B<as_string>
 
-Returns the entry formatted as an OpenSSH authorized_keys line.
+Returns the entry formatted as an OpenSSH authorized_keys line. Throws
+an exception if no key material present in the instance.
 
 =item B<duplicate_of> I<optional value>
 
@@ -539,6 +559,10 @@ returns the value of this data, which is C<0> by default. Used by
 L<Config::OpenSSH::Authkey> to track whether (and of what) a key is a
 duplicate of.
 
+=item B<unset_duplicate>
+
+Clears the duplicate status of the instance, if any.
+
 =back
 
 =head1 BUGS
